'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = {
    data: function data() {
        return {
            results: 0,
            totalResults: 0
        };
    },


    directives: {
        'list-item': {
            inserted: function inserted(el, binding, vnode) {
                vnode.context.applyQueryToListItem(el, binding.value);
            },
            componentUpdated: function componentUpdated(el, binding, vnode) {
                vnode.context.applyQueryToListItem(el, binding.value);
            }
        }
    },

    watch: {
        query: {
            handler: function handler() {
                var _this = this;

                this.$nextTick(function () {
                    return _this.countResults();
                });
            },

            deep: true
        }
    },

    mounted: function mounted() {
        this.countResults();
        this.countTotalResults();
    },


    methods: {
        shouldShow: function shouldShow(item) {
            // eslint-disable-line no-unused-vars
            return true;
        },
        applyQueryToListItem: function applyQueryToListItem(el, item) {
            if (this.shouldShow(item)) {
                this.showListItem(el);
                return;
            }
            this.hideListItem(el);
        },
        showListItem: function showListItem(el) {
            el.setAttribute('data-matches-query', 'true');

            if (this.$options.hiddenClass) {
                el.classList.remove(this.$options.hiddenClass);
            } else {
                el.style.display = '';
            }
        },
        hideListItem: function hideListItem(el) {
            el.setAttribute('data-matches-query', 'false');

            if (this.$options.hiddenClass) {
                el.classList.add(this.$options.hiddenClass);
            } else {
                el.style.display = 'none';
            }
        },
        countResults: function countResults() {
            this.results = this.$el.querySelectorAll('[data-matches-query=true]').length;
        },
        countTotalResults: function countTotalResults() {
            this.totalResults = this.$el.querySelectorAll('[data-matches-query]').length;
        }
    }
};